:: This batch runs in a loop to convert incoming .BMP files to .jpgs.
:: Its purpose is to save space, and in that turn also save the .jpg files somewhere else than the busy source.
:: The test1.txt / test2.txt / test3.txt trick allows a sort of multithreading from a batch file.
:: It allows to start the first in foreground, the second in background and the third in background.
:: Needed since Imagemagik-Convert is single-threaded and therefore too slow to convert fast enough to avoid the source running out of space.
::
:: (c) 2019 Joachim Otahal, jou@gmx.net and youtube@joumxyzptlk.de

@echo off

:start
:: Destination directory
mkdir E:\tmp\Bandicam 2>NUL
:: Source directory, in my case a mapped network drive from the recording computer.
:: This moves all movable source files out of the way. The purpose is to avoid access conflicts while the main computer is still capturing.
mkdir b:\temp 2>NUL
move B:\*.bmp b:\temp 2>NUL

:: Process the .BMPs
for %%f in (b:\temp\*.bmp) do (
       echo %%f
:: Part of "Multithread" control.
       if not exist %temp%\test1.txt if not exist %temp%\test2.txt if not exist %temp%\test3.txt copy NUL %temp%\test1.txt > NUL

:: the actual conversion in up to three threads
       if exist %temp%\test1.txt "C:\Program Files\ImageMagick-7.0.8-Q16\convert.exe" "b:\temp\%%~nf.bmp" -quality 92 "e:\tmp\Bandicam\%%~nf.jpg"       
       if exist %temp%\test2.txt start "" /MIN "C:\Program Files\ImageMagick-7.0.8-Q16\convert.exe" "b:\temp\%%~nf.bmp" -quality 92 "e:\tmp\Bandicam\%%~nf.jpg"
       if exist %temp%\test3.txt start "" /MIN "C:\Program Files\ImageMagick-7.0.8-Q16\convert.exe" "b:\temp\%%~nf.bmp" -quality 92 "e:\tmp\Bandicam\%%~nf.jpg"

:: Part of "Multithread" control.
       if exist %temp%\test3.txt del %temp%\test3.txt
       if exist %temp%\test2.txt ren %temp%\test2.txt test3.txt
       if exist %temp%\test1.txt ren %temp%\test1.txt test2.txt
)
:: Clean up temp on source after conversion.
rd /s /q b:\temp 2>NUL
:: This avoids racing the batch at full speed if there is nothing to do.
ping -n 2 127.0.0.1 >NUL
goto :start